//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Model/RealModel.h
//! @brief     Defines class RealModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_MODEL_REALMODEL_H
#define BORNAGAIN_GUI_MODEL_MODEL_REALMODEL_H

#include "GUI/Model/Model/SessionModel.h"

class RealItem;
class DataItem;

//! The RealModel class is a model to store all imported RealItem's.
class RealModel : public SessionModel {
    Q_OBJECT

public:
    explicit RealModel(QObject* parent = nullptr);
    ~RealModel();

    QVector<DataItem*> dataItems() const;
    void clear() override;
    void writeTo(QXmlStreamWriter* w) const override;
    void readFrom(QXmlStreamReader* r, MessageService* messageService = nullptr) override;

    RealItem* createRealItem();
    RealItem* insertSpecularDataItem();
    RealItem* insertIntensityDataItem();
    RealItem* insertDataItem(int rank);
    QVector<RealItem*> realItems() const;
    QVector<RealItem*> realItems(int rank) const;

    QVector<RealItem*> realItems1D() const;
    QVector<RealItem*> realItems2D() const;

    void removeRealItem(RealItem* realItem);

    QStringList realItemNames() const;

signals:
    // this signal is used only for testing
    void realDataAddedOrRemoved();

private:
    std::vector<std::unique_ptr<RealItem>> m_realItems;
};

#endif // BORNAGAIN_GUI_MODEL_MODEL_REALMODEL_H
