//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/DepthprobeInstrumentEditor.cpp
//! @brief     Implements class DepthprobeInstrumentEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/DepthprobeInstrumentEditor.h"
#include "GUI/Model/Device/BeamWavelengthItem.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/View/Instrument/AxisPropertyEditor.h"
#include "GUI/View/Instrument/DistributionEditor.h"
#include "GUI/View/Instrument/InclinationAnglesEditor.h"
#include "GUI/View/Instrument/PolarizationAnalysisEditor.h"
#include "GUI/View/Instrument/SphericalAxisEditor.h"
#include "GUI/View/Tool/GroupBoxCollapser.h"
#include <QGridLayout>
#include <QVBoxLayout>

DepthprobeInstrumentEditor::DepthprobeInstrumentEditor(QWidget* parent,
                                                       DepthprobeInstrumentItem* instrument)
    : QWidget(parent)
{
    ASSERT(instrument);
    auto* layout = new QVBoxLayout(this);
    layout->setContentsMargins(0, 0, 0, 0);

    auto* parametersGroupBox = new QGroupBox(this);
    parametersGroupBox->setTitle("Parameters");
    auto* vLayout = new QVBoxLayout(parametersGroupBox);
    vLayout->setContentsMargins(30, 8, 0, 0);

    auto* m_wavelengthEditor =
        new DistributionEditor("Wavelength", MeanConfig{true}, GUI::ID::Distributions::Symmetric,
                               this, instrument->beamItem()->wavelengthItem());
    vLayout->addWidget(m_wavelengthEditor);

    auto* inclinationEditor =
        new InclinationAnglesEditor(this, instrument->beamItem()->inclinationAngleItem());
    vLayout->addWidget(inclinationEditor);

    auto* depthAxisEditor = new AxisPropertyEditor(this, "Depth axis", &instrument->zAxis(),
                                                   "Number of points in scan across sample bulk");
    vLayout->addWidget(depthAxisEditor);

    GroupBoxCollapser::installIntoGroupBox(parametersGroupBox);
    layout->addWidget(parametersGroupBox);

    auto* polMatricesAnalysisEditor = new PolarizationAnalysisEditor(this, instrument);
    layout->addWidget(polMatricesAnalysisEditor);

    layout->addStretch();

    connect(m_wavelengthEditor, &DistributionEditor::distributionChanged, this,
            &DepthprobeInstrumentEditor::dataChanged);
    connect(inclinationEditor, &InclinationAnglesEditor::dataChanged, this,
            &DepthprobeInstrumentEditor::dataChanged);
    connect(depthAxisEditor, &AxisPropertyEditor::dataChanged, this,
            &DepthprobeInstrumentEditor::dataChanged);
    connect(polMatricesAnalysisEditor, &PolarizationAnalysisEditor::dataChanged, this,
            &DepthprobeInstrumentEditor::dataChanged);
}
