//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Projection/ProjectionsPlot.h
//! @brief     Defines class ProjectionsPlot
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_PROJECTION_PROJECTIONSPLOT_H
#define BORNAGAIN_GUI_VIEW_PROJECTION_PROJECTIONSPLOT_H

#include "GUI/View/Common/DataItemBundleWidget.h"
#include "qcustomplot.h"
#include <QMap>
#include <memory>

class IntensityDataItem;
class ProjectionContainerItem;
class Datafield;
class QCPGraph;

//! A customplot based widget to display projections of IntensityDataItem on X,Y axes.

class ProjectionsPlot : public DataItemBundleWidget {
    Q_OBJECT

public:
    ProjectionsPlot(QString projectionType, QWidget* parent = nullptr);

    void setIntensityItem(IntensityDataItem* intensityDataItem) override;

    void connectItems();
    void disconnectItems();

public slots:
    void onMarginsChanged(double left, double right);

private:
    IntensityDataItem* intensityItem();
    QVector<SessionItem*> projectionItems();
    QCPGraph* graphForItem(SessionItem* item);

    void updateProjectionsData();
    void updateProjections();
    void onProjectionPropertyChanged(SessionItem* item);
    void updateAxesRange();
    void updateAxesTitle();
    void clearProjection(SessionItem* item);
    void clearAll();

    void setGraphFromItem(QCPGraph* graph, SessionItem* item);

    void setInterpolate(bool isInterpolated);
    void setLogz(bool isLogz);

    void replot();

    bool isHorizontalType();

    QString m_projectionType;
    QCustomPlot* m_customPlot;
    QMap<SessionItem*, QCPGraph*> m_item_to_graph;
};

#endif // BORNAGAIN_GUI_VIEW_PROJECTION_PROJECTIONSPLOT_H
