//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Element/SpecularElement.cpp
//! @brief     Implements the class SpecularElement.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Resample/Element/SpecularElement.h"
#include "Base/Vector/GisasDirection.h"
#include "Resample/Slice/KzComputation.h"

SpecularElement SpecularElement::FromQzScan(double kz, const SpinMatrix& polarizer,
                                            const SpinMatrix& analyzer, bool computable)
{
    return {computable, polarizer, analyzer,
            [kz](const SliceStack& slices) { return Compute::Kz::computeKzFromSLDs(slices, kz); }};
}

SpecularElement SpecularElement::FromAlphaScan(double wavelength, double alpha,
                                               const SpinMatrix& polarizer,
                                               const SpinMatrix& analyzer, bool computable)
{
    return {computable, polarizer, analyzer,
            [k = vecOfLambdaAlphaPhi(wavelength, alpha)](const SliceStack& slices) {
                return Compute::Kz::computeKzFromRefIndices(slices, k);
            }};
}

SpecularElement::SpecularElement(bool computable, const SpinMatrix& polarizer,
                                 const SpinMatrix& analyzer,
                                 std::function<std::vector<complex_t>(const SliceStack&)> kz_comp)
    : IElement(polarizer, analyzer)
    , m_intensity(0.0)
    , m_computable(computable)
    , m_kz_computation(kz_comp)
{
}

SpecularElement::SpecularElement(SpecularElement&& other) noexcept = default;

SpecularElement::~SpecularElement() = default;

std::vector<complex_t> SpecularElement::produceKz(const SliceStack& slices)
{
    return m_kz_computation(slices);
}
