"""
BornAgain collection of standard simulation setups.
"""
import bornagain as ba
from bornagain import deg, angstrom


def specular(sample, scan_size):
    """
    Returns a standard specular simulation.
    """
    scan = ba.AlphaScan(1.54*angstrom, scan_size, 0, 2*deg)
    return ba.SpecularSimulation(scan, sample)


def sas(sample, npix):
    """
    Returns a standard simulation in small-angle scattering geometry.
    Incident beam is almost horizontal.
    """
    beam = ba.UnitBeam(1*angstrom, 1e-8*deg)
    det = ba.SphericalDetector(npix, 10*deg, 0, 0)
    return ba.ScatteringSimulation(beam, sample, det)
